@@ -91,13 +91,16 @@ class _SubtypeAssigner(pytree_visitor.PyTreeVisitor):
             else:
               _AppendFirstLeafTokenSubtype(
                   child, format_token.Subtype.DICTIONARY_VALUE)
-          elif (child is not None and (isinstance(child, pytree.Node) or (
-              not child.value.startswith('#') and child.value not in '{:,'))):
+          elif (
+              child is not None and
+              (isinstance(child, pytree.Node) or
+               (not child.value.startswith('#') and child.value not in '{:,'))):
             # Mark the first leaf of a key entry as a DICTIONARY_KEY. We
             # normally want to split before them if the dictionary cannot exist
             # on a single line.
             _AppendFirstLeafTokenSubtype(child,
                                          format_token.Subtype.DICTIONARY_KEY)
+            _AppendSubtypeRec(child, format_token.Subtype.DICTIONARY_KEY_PART)
         last_was_colon = pytree_utils.NodeName(child) == 'COLON'
 
   def Visit_expr_stmt(self, node):  # pylint: disable=invalid-name
@@ -303,8 +306,10 @@ class _SubtypeAssigner(pytree_visitor.PyTreeVisitor):
 
 
 def _SetDefaultOrNamedAssignArgListSubtype(node):
+  """Set named assign subtype on elements in a arg list."""
 
   def HasDefaultOrNamedAssignSubtype(node):
+    """Return True if the arg list has a named assign subtype."""
     if isinstance(node, pytree.Leaf):
       if (format_token.Subtype.DEFAULT_OR_NAMED_ASSIGN in
           pytree_utils.GetNodeAnnotation(node, pytree_utils.Annotation.SUBTYPE,
